
# A Pure Python implementtation of Calculator over ECC Groups


* in `tests/test_bitcoin_genpub.py` you can check the bitcoin case, verified with `Vitalik Buterin`'s `pybitcointools`.

Note that, this implementation may cause 10 times slower than `Vitalik Buterin`'s `fast jacobian` implementation.
